@@ -1,25 +1,22 @@
 package Music::Interval::Barycentric;
-BEGIN {
-  $Music::Interval::Barycentric::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 # ABSTRACT: Compute barycentric musical interval space
 
 use strict;
 use warnings;
 
 use List::Util qw( min );
+use Readonly;
 
-use constant {
-    SIZE  => 3,  # Triad chord
-    SCALE => 12, # Scale notes
-};
+Readonly my $SIZE  => 3;  # Triad chord
+Readonly my $SCALE => 12; # Scale notes
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 
 sub barycenter {
-    my $size  = shift || SIZE;  # Default to a triad
-    my $scale = shift || SCALE; # Default to the common scale notes
+    my $size  = shift || $SIZE;  # Default to a triad
+    my $scale = shift || $SCALE; # Default to the common scale notes
     return ($scale / $size) x $size;
 }
 
@@ -87,16 +84,17 @@ Music::Interval::Barycentric - Compute barycentric musical interval space
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
- print join(', ', barycenter(3)), "\n";
+ use Music::Interval::Barycentric;
+ print join(', ', Music::Interval::Barycentric::barycenter(3)), "\n";
  @chords = [qw(3 4 5), qw(0 4 7)];
- printf "D: %.3f\n", distance($chords[0], $chords[1]);
- print evenness_index($chords[0]);
- print orbit_distance(@chords), "\n";
- print forte_distance(@chords), "\n";
+ printf "D: %.3f\n", Music::Interval::Barycentric::distance($chords[0], $chords[1]);
+ print Music::Interval::Barycentric::evenness_index($chords[0]);
+ print Music::Interval::Barycentric::orbit_distance(@chords), "\n";
+ print Music::Interval::Barycentric::forte_distance(@chords), "\n";
 
 =head1 DESCRIPTION
 
@@ -147,17 +145,8 @@ Return a chord distance from the barycenter.
 
 =head1 SEE ALSO
 
-http://www.amazon.com/Geometry-Musical-Chords-Interval-Representation/dp/145022797X
-
-=head1 AUTHOR
-
-Gene Boggs E<lt>gene@cpan.orgE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2012, Gene Boggs
-
-This code is licensed under the same terms as Perl itself.
+L<http://www.amazon.com/Geometry-Musical-Chords-Interval-Representation/dp/145022797X>
+"A New Geometry of Musical Chords in Interval Representation: Dissonance, Enrichment, Degeneracy and Complementation"
 
 =head1 AUTHOR
 
@@ -165,7 +154,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
